package com.xkrs.newpro.service.impl;

import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.newpro.dao.QcItemDao;
import com.xkrs.newpro.dao.QcSpecDao;
import com.xkrs.newpro.model.entity.QcItemEntity;
import com.xkrs.newpro.model.entity.QcSpecEntity;
import com.xkrs.newpro.model.qo.QcSpecQoInsert;
import com.xkrs.newpro.model.qo.QcSpecQoUpdate;
import com.xkrs.newpro.service.QcSpecService;
import com.xkrs.newpro.utils.LocalDateUtils;
import com.xkrs.newpro.utils.LocalStringUtils;
import org.springframework.context.i18n.LocaleContextHolder;

import javax.annotation.Resource;
import java.util.Locale;
import java.util.Optional;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

public class QcSpecServiceImpl implements QcSpecService {

    private Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private QcItemDao qcItemDao;

    @Resource
    private QcSpecDao qcSpecDao;

    /**
     * 添加质检规格
     */
    @Override
    public String insertQcSpec(QcSpecQoInsert insertQo) {

        String varietyNo = insertQo.getVarietyNo();
        String qcItemNo = insertQo.getQcItemNo();
        String max = insertQo.getMax();
        String mean = insertQo.getMean();
        String min = insertQo.getMin();
        String unit = insertQo.getUnit();
        String method = insertQo.getMethod();
        String standard = insertQo.getStandard();
        String remark = insertQo.getRemark();

        Optional<QcItemEntity> entityByNo = qcItemDao.findByNo(qcItemNo);
        if (entityByNo.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "不存在该检验项目，请先添加检验项目！", locale);
        }

        Optional<QcSpecEntity> entityByVarietyNoAndQcItemNo = qcSpecDao.findByVarietyNoAndQcItemNo(varietyNo, qcItemNo);
        if (entityByVarietyNoAndQcItemNo.isPresent()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_EXIT, "该检验规格已存在，请勿重复添加！", locale);
        }
        QcSpecEntity entity = new QcSpecEntity();
        entity.setCreateTime(LocalDateUtils.getCurrentSecond());
        entity.setUpdateTime("");
        entity.setVarietyNo(varietyNo);
        entity.setQcItemNo(qcItemNo);
        entity.setMax(LocalStringUtils.formatEmptyValue(max));
        entity.setMean(LocalStringUtils.formatEmptyValue(mean));
        entity.setMin(LocalStringUtils.formatEmptyValue(min));
        entity.setUnit(LocalStringUtils.formatEmptyValue(unit));
        entity.setMethod(LocalStringUtils.formatEmptyValue(method));
        entity.setStandard(LocalStringUtils.formatEmptyValue(standard));
        entity.setRemark(LocalStringUtils.formatEmptyValue(remark));
        qcSpecDao.save(entity);

        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "添加成功！", locale);
    }

    @Override
    public String updateQcSpec(QcSpecQoUpdate updateQo) {
        return null;
    }
}
